@@ -21,6 +21,7 @@
 # Copyright (c) 2019 Hugues <hugues.bruant@affirm.com>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2020 Pieter Engelbrecht <pengelbrecht@rems2.com>
 # Copyright (c) 2020 Clément Pit-Claudel <cpitclaudel@users.noreply.github.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 
@@ -656,6 +657,15 @@ class TestRunTC:
             ],
             code=0,
         )
+        self._runtest(
+            [
+                "--fail-under",
+                "5.5",
+                "--enable=all",
+                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+            ],
+            code=0,
+        )
         self._runtest(
             [
                 "--fail-under",
@@ -665,6 +675,15 @@ class TestRunTC:
             ],
             code=16,
         )
+        self._runtest(
+            [
+                "--fail-under",
+                "6.7",
+                "--enable=all",
+                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+            ],
+            code=16,
+        )
 
         self._runtest(
             [
@@ -783,3 +802,19 @@ class TestRunTC:
         path = join(HERE, "regrtest_data", "unused_variable.py")
         expected = "Your code has been rated at 7.50/10"
         self._test_output([path, "--jobs=2", "-ry"], expected_output=expected)
+
+    def test_duplicate_code_raw_strings(self):
+        path = join(HERE, "regrtest_data", "duplicate_data_raw_strings")
+        expected_output = "Similar lines in 2 files"
+        self._test_output(
+            [path, "--disable=all", "--enable=duplicate-code"],
+            expected_output=expected_output,
+        )
+
+    def test_regression_parallel_mode_without_filepath(self):
+        # Test that parallel mode properly passes filepath
+        # https://github.com/PyCQA/pylint/issues/3564
+        path = join(
+            HERE, "regrtest_data", "regression_missing_init_3564", "subdirectory/"
+        )
+        self._test_output([path, "-j2"], expected_output="No such file or directory")
